netapp_ontap.models.flexcache_prepopulate API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.flexcache_prepopulate`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FlexcachePrepopulateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FlexcachePrepopulate object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `dir_paths POST PATCH`

    The dir_paths field of the flexcache_prepopulate.

  `recurse POST PATCH`

    Specifies whether or not the prepopulate action should search through the directory-path recursively. If not set, the default value "true" is used.